==> transmission-1.51.tar.bz2: transmission-1.51/gtk/dialogs.h <==
/******************************************************************************
 * $Id: dialogs.h 6795 2008-09-23 19:11:04Z charles $
 *
 * Copyright (c) 2005-2008 Transmission authors and contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *****************************************************************************/

#ifndef TG_PREFS_H
#define TG_PREFS_H

#include "tr-core.h"
#include "tr-torrent.h"
#include "util.h"

/* prompt if the user wants to quit, calls func with cbdata if they do */
void askquit(                               TrCore*,
                             GtkWindow*     parent,
                             callbackfunc_t func,
                             void*          cbdata );

void confirmRemove( GtkWindow * parent,
                    TrCore *    core,
                    GSList *    gtorrents,
                    gboolean    doDelete );

#endif /* TG_PREFS_H */

==> transmission-1.76.tar.bz2: transmission-1.76/gtk/dialogs.h <==
/******************************************************************************
 * $Id: dialogs.h 8846 2009-07-22 15:55:48Z charles $
 *
 * Copyright (c) 2005-2008 Transmission authors and contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *****************************************************************************/

#ifndef TG_PREFS_H
#define TG_PREFS_H

#include "tr-core.h"
#include "tr-torrent.h"
#include "util.h"


/* used for a callback function with a data parameter */
typedef void ( *callbackfunc_t )( gpointer );

/* prompt if the user wants to quit, calls func with cbdata if they do */
void askquit( TrCore          * core,
              GtkWindow       * parent,
              callbackfunc_t    func,
              gpointer          cbdata );

void confirmRemove( GtkWindow * parent,
                    TrCore    * core,
                    GSList    * gtorrents,
                    gboolean    doDelete );

#endif /* TG_PREFS_H */
